==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/wavpack/translations/wavpack_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>Modul WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="132"/>
        <source>About WavPack Audio Plugin</source>
        <translation>O modulu WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="133"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Vstupní modul Qmmp WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="134"/>
        <source>WavPack library version:</source>
        <translation>Verze knihovny WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="136"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>Soubory WavPack</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="66"/>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
        <source>Sample rate</source>
        <translation>Vzorkovací frekvence</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
        <source>Channels</source>
        <translation>Počet kanálů</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="69"/>
        <source>Bitrate</source>
        <translation>Datový tok</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="69"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>File size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Ratio</source>
        <translation>Poměr</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.2.orig.tar.gz: qmmp-0.5.2/src/plugins/Input/wavpack/translations/wavpack_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>Modul WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="153"/>
        <source>About WavPack Audio Plugin</source>
        <translation>O modulu WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="154"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Vstupní modul Qmmp WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="155"/>
        <source>WavPack library version:</source>
        <translation>Verze knihovny WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="157"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>Soubory WavPack</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
        <source>Sample rate</source>
        <translation>Vzorkovací frekvence</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="69"/>
        <source>Channels</source>
        <translation>Počet kanálů</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Bitrate</source>
        <translation>Datový tok</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>File size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Ratio</source>
        <translation>Poměr</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="74"/>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
</context>
</TS>
